SHA256
1
0
forked from pool/eog
eog/eog-fast-image-switch-crash.patch

37 lines
1.1 KiB
Diff

Index: libeog/eog-image.c
===================================================================
--- libeog/eog-image.c.orig
+++ libeog/eog-image.c
@@ -855,8 +855,7 @@ eog_image_load (EogImage *img, guint dat
}
if (eog_image_has_data (img, data2read)) {
- g_warning ("Image %s has requested data already loaded.\n",
- eog_image_get_caption (img));
+ return TRUE;
}
if (priv->status == EOG_IMAGE_STATUS_FAILED) {
Index: shell/eog-window.c
===================================================================
--- shell/eog-window.c.orig
+++ shell/eog-window.c
@@ -3500,10 +3500,13 @@ handle_image_selection_changed (EogWrapL
data = g_new0 (EogJobImageLoadData, 1);
EOG_JOB_DATA (data)->window = window;
- data->image = image; /* no additional ref required, since
- * its already increased by
- * eog_wrap_list_get_first_selected_image
- */
+
+ data->image = eog_image_data_ref (image);
+
+ /* Need to unref this, because the refcount was already
+ * increased by eog_wrap_list_get_first_selected_image
+ */
+ g_object_unref (image);
job = eog_job_new_full (data,
job_image_load_action,